@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from subprocess import Popen, PIPE
+import os
 
 SCHROOT_BIN = 'schroot'
 
@@ -22,6 +23,7 @@ class Schroot(object):
         return cmd
 
     def __init__(self, chroot_name):
+        os.chdir('/')
         self.__chroot_name = chroot_name
         self.__start_session()
 
@@ -40,10 +42,7 @@ class Schroot(object):
             '-c', self.__session,
             '--' ] + list(args)
         )
-        return cmd.stdout
-
-    def close(self):
-        del(self)
+        return cmd
 
     def __del__(self):
         if not self.__session:
@@ -53,4 +52,4 @@ class Schroot(object):
             SCHROOT_BIN,
             '-e',
             '-c', self.__session
-        ])
+        ]).wait()
